@@ -1,4 +1,4 @@
-# Copyright (C) 2002-2021 S[&]T, The Netherlands.
+# Copyright (C) 2002-2022 S[&]T, The Netherlands.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -199,6 +199,9 @@ class ValueSlider(wx.Panel):
         self.text.SetValue(str(int(value)))
 
     def SetRange(self, minValue, maxValue):
+        minValue = int(minValue)
+        maxValue = int(maxValue)
+
         if minValue != self.minValue or maxValue != self.maxValue:
             self.minValue = minValue
             self.maxValue = maxValue
